/**
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.deephacks.tools4j.config.internal.cached;

import com.esotericsoftware.kryo.Kryo;
import com.esotericsoftware.kryo.Serializer;
import com.esotericsoftware.kryo.io.Input;
import com.esotericsoftware.kryo.io.Output;

import java.net.MalformedURLException;
import java.net.URI;
import java.net.URL;

/**
 * Classes that help Kryo to read and write objects that it cannot do
 * on its own.
 */
public class KryoSerializers  {

    public static final class URISerializer extends Serializer<URI> {
        @Override
        public void write(Kryo kryo, Output output, URI uri) {
            output.writeString(uri.toString());
        }

        @Override
        public URI read(Kryo kryo, Input input, Class<URI> uriClass) {
            return URI.create(input.readString());
        }
    }

    public static final class URLSerializer extends Serializer<URL> {
        @Override
        public void write(Kryo kryo, Output output, URL url) {
            output.writeString(url.toString());
        }

        @Override
        public URL read(Kryo kryo, Input input, Class<URL> urlClass) {
            try {
                return new URL(input.readString());
            } catch (MalformedURLException e) {
                throw new RuntimeException(e);
            }
        }
    }

}